/*
 * Grafana HTTP API.
 *
 * The Grafana backend exposes an HTTP API, the same API is used by the frontend to do everything from saving dashboards, creating users and updating data sources.
 *
 * API version: 0.0.1
 * Contact: hello@grafana.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */
package swagger

import (
	"fmt"
	"net/http"
	"strings"

	"github.com/gorilla/mux"
)

type Route struct {
	Name        string
	Method      string
	Pattern     string
	HandlerFunc http.HandlerFunc
}

type Routes []Route

func NewRouter() *mux.Router {
	router := mux.NewRouter().StrictSlash(true)
	for _, route := range routes {
		var handler http.Handler
		handler = route.HandlerFunc
		handler = Logger(handler, route.Name)

		router.
			Methods(route.Method).
			Path(route.Pattern).
			Name(route.Name).
			Handler(handler)
	}

	return router
}

func Index(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "Hello World!")
}

var routes = Routes{
	Route{
		"Index",
		"GET",
		"/",
		Index,
	},

	Route{
		"AddTeamRole",
		strings.ToUpper("Post"),
		"/access-control/teams/{teamId}/roles",
		AddTeamRole,
	},

	Route{
		"AddUserRole",
		strings.ToUpper("Post"),
		"/access-control/users/{userId}/roles",
		AddUserRole,
	},

	Route{
		"CreateRole",
		strings.ToUpper("Post"),
		"/access-control/roles",
		CreateRole,
	},

	Route{
		"DeleteRole",
		strings.ToUpper("Delete"),
		"/access-control/roles/{roleUID}",
		DeleteRole,
	},

	Route{
		"GetAccessControlStatus",
		strings.ToUpper("Get"),
		"/access-control/status",
		GetAccessControlStatus,
	},

	Route{
		"GetResourceDescription",
		strings.ToUpper("Get"),
		"/access-control/{resource}/description",
		GetResourceDescription,
	},

	Route{
		"GetResourcePermissions",
		strings.ToUpper("Get"),
		"/access-control/{resource}/{resourceID}",
		GetResourcePermissions,
	},

	Route{
		"GetRole",
		strings.ToUpper("Get"),
		"/access-control/roles/{roleUID}",
		GetRole,
	},

	Route{
		"GetRoleAssignments",
		strings.ToUpper("Get"),
		"/access-control/roles/{roleUID}/assignments",
		GetRoleAssignments,
	},

	Route{
		"ListRoles",
		strings.ToUpper("Get"),
		"/access-control/roles",
		ListRoles,
	},

	Route{
		"ListTeamRoles",
		strings.ToUpper("Get"),
		"/access-control/teams/{teamId}/roles",
		ListTeamRoles,
	},

	Route{
		"ListTeamsRoles",
		strings.ToUpper("Post"),
		"/access-control/teams/roles/search",
		ListTeamsRoles,
	},

	Route{
		"ListUserRoles",
		strings.ToUpper("Get"),
		"/access-control/users/{userId}/roles",
		ListUserRoles,
	},

	Route{
		"ListUsersRoles",
		strings.ToUpper("Post"),
		"/access-control/users/roles/search",
		ListUsersRoles,
	},

	Route{
		"RemoveTeamRole",
		strings.ToUpper("Delete"),
		"/access-control/teams/{teamId}/roles/{roleUID}",
		RemoveTeamRole,
	},

	Route{
		"RemoveUserRole",
		strings.ToUpper("Delete"),
		"/access-control/users/{userId}/roles/{roleUID}",
		RemoveUserRole,
	},

	Route{
		"SetResourcePermissions",
		strings.ToUpper("Post"),
		"/access-control/{resource}/{resourceID}",
		SetResourcePermissions,
	},

	Route{
		"SetResourcePermissionsForBuiltInRole",
		strings.ToUpper("Post"),
		"/access-control/{resource}/{resourceID}/builtInRoles/{builtInRole}",
		SetResourcePermissionsForBuiltInRole,
	},

	Route{
		"SetResourcePermissionsForTeam",
		strings.ToUpper("Post"),
		"/access-control/{resource}/{resourceID}/teams/{teamID}",
		SetResourcePermissionsForTeam,
	},

	Route{
		"SetResourcePermissionsForUser",
		strings.ToUpper("Post"),
		"/access-control/{resource}/{resourceID}/users/{userID}",
		SetResourcePermissionsForUser,
	},

	Route{
		"SetRoleAssignments",
		strings.ToUpper("Put"),
		"/access-control/roles/{roleUID}/assignments",
		SetRoleAssignments,
	},

	Route{
		"SetTeamRoles",
		strings.ToUpper("Put"),
		"/access-control/teams/{teamId}/roles",
		SetTeamRoles,
	},

	Route{
		"SetUserRoles",
		strings.ToUpper("Put"),
		"/access-control/users/{userId}/roles",
		SetUserRoles,
	},

	Route{
		"UpdateRole",
		strings.ToUpper("Put"),
		"/access-control/roles/{roleUID}",
		UpdateRole,
	},

	Route{
		"AdminProvisioningReloadAccessControl",
		strings.ToUpper("Post"),
		"/admin/provisioning/access-control/reload",
		AdminProvisioningReloadAccessControl,
	},

	Route{
		"AdminGetSettings",
		strings.ToUpper("Get"),
		"/admin/settings",
		AdminGetSettings,
	},

	Route{
		"AdminGetStats",
		strings.ToUpper("Get"),
		"/admin/stats",
		AdminGetStats,
	},

	Route{
		"GetLDAPStatus",
		strings.ToUpper("Get"),
		"/admin/ldap/status",
		GetLDAPStatus,
	},

	Route{
		"GetUserFromLDAP",
		strings.ToUpper("Get"),
		"/admin/ldap/{user_name}",
		GetUserFromLDAP,
	},

	Route{
		"PostSyncUserWithLDAP",
		strings.ToUpper("Post"),
		"/admin/ldap/sync/{user_id}",
		PostSyncUserWithLDAP,
	},

	Route{
		"ReloadLDAPCfg",
		strings.ToUpper("Post"),
		"/admin/ldap/reload",
		ReloadLDAPCfg,
	},

	Route{
		"AdminProvisioningReloadDashboards",
		strings.ToUpper("Post"),
		"/admin/provisioning/dashboards/reload",
		AdminProvisioningReloadDashboards,
	},

	Route{
		"AdminProvisioningReloadDatasources",
		strings.ToUpper("Post"),
		"/admin/provisioning/datasources/reload",
		AdminProvisioningReloadDatasources,
	},

	Route{
		"AdminProvisioningReloadPlugins",
		strings.ToUpper("Post"),
		"/admin/provisioning/plugins/reload",
		AdminProvisioningReloadPlugins,
	},

	Route{
		"AdminCreateUser",
		strings.ToUpper("Post"),
		"/admin/users",
		AdminCreateUser,
	},

	Route{
		"AdminDeleteUser",
		strings.ToUpper("Delete"),
		"/admin/users/{user_id}",
		AdminDeleteUser,
	},

	Route{
		"AdminDisableUser",
		strings.ToUpper("Post"),
		"/admin/users/{user_id}/disable",
		AdminDisableUser,
	},

	Route{
		"AdminEnableUser",
		strings.ToUpper("Post"),
		"/admin/users/{user_id}/enable",
		AdminEnableUser,
	},

	Route{
		"AdminGetUserAuthTokens",
		strings.ToUpper("Get"),
		"/admin/users/{user_id}/auth-tokens",
		AdminGetUserAuthTokens,
	},

	Route{
		"AdminLogoutUser",
		strings.ToUpper("Post"),
		"/admin/users/{user_id}/logout",
		AdminLogoutUser,
	},

	Route{
		"AdminRevokeUserAuthToken",
		strings.ToUpper("Post"),
		"/admin/users/{user_id}/revoke-auth-token",
		AdminRevokeUserAuthToken,
	},

	Route{
		"AdminUpdateUserPassword",
		strings.ToUpper("Put"),
		"/admin/users/{user_id}/password",
		AdminUpdateUserPassword,
	},

	Route{
		"AdminUpdateUserPermissions",
		strings.ToUpper("Put"),
		"/admin/users/{user_id}/permissions",
		AdminUpdateUserPermissions,
	},

	Route{
		"GetUserQuota",
		strings.ToUpper("Get"),
		"/admin/users/{user_id}/quotas",
		GetUserQuota,
	},

	Route{
		"UpdateUserQuota",
		strings.ToUpper("Put"),
		"/admin/users/{user_id}/quotas/{quota_target}",
		UpdateUserQuota,
	},

	Route{
		"DeleteAnnotationByID",
		strings.ToUpper("Delete"),
		"/annotations/{annotation_id}",
		DeleteAnnotationByID,
	},

	Route{
		"GetAnnotationByID",
		strings.ToUpper("Get"),
		"/annotations/{annotation_id}",
		GetAnnotationByID,
	},

	Route{
		"GetAnnotationTags",
		strings.ToUpper("Get"),
		"/annotations/tags",
		GetAnnotationTags,
	},

	Route{
		"GetAnnotations",
		strings.ToUpper("Get"),
		"/annotations",
		GetAnnotations,
	},

	Route{
		"MassDeleteAnnotations",
		strings.ToUpper("Post"),
		"/annotations/mass-delete",
		MassDeleteAnnotations,
	},

	Route{
		"PatchAnnotation",
		strings.ToUpper("Patch"),
		"/annotations/{annotation_id}",
		PatchAnnotation,
	},

	Route{
		"PostAnnotation",
		strings.ToUpper("Post"),
		"/annotations",
		PostAnnotation,
	},

	Route{
		"PostGraphiteAnnotation",
		strings.ToUpper("Post"),
		"/annotations/graphite",
		PostGraphiteAnnotation,
	},

	Route{
		"UpdateAnnotation",
		strings.ToUpper("Put"),
		"/annotations/{annotation_id}",
		UpdateAnnotation,
	},

	Route{
		"AddAPIkey",
		strings.ToUpper("Post"),
		"/auth/keys",
		AddAPIkey,
	},

	Route{
		"DeleteAPIkey",
		strings.ToUpper("Delete"),
		"/auth/keys/{id}",
		DeleteAPIkey,
	},

	Route{
		"GetAPIkeys",
		strings.ToUpper("Get"),
		"/auth/keys",
		GetAPIkeys,
	},

	Route{
		"CreateCorrelation",
		strings.ToUpper("Post"),
		"/datasources/uid/{sourceUID}/correlations",
		CreateCorrelation,
	},

	Route{
		"DeleteCorrelation",
		strings.ToUpper("Delete"),
		"/datasources/uid/{uid}/correlations/{correlationUID}",
		DeleteCorrelation,
	},

	Route{
		"GetCorrelation",
		strings.ToUpper("Get"),
		"/datasources/uid/{sourceUID}/correlations/{correlationUID}",
		GetCorrelation,
	},

	Route{
		"GetCorrelations",
		strings.ToUpper("Get"),
		"/datasources/correlations",
		GetCorrelations,
	},

	Route{
		"GetCorrelationsBySourceUID",
		strings.ToUpper("Get"),
		"/datasources/uid/{sourceUID}/correlations",
		GetCorrelationsBySourceUID,
	},

	Route{
		"UpdateCorrelation",
		strings.ToUpper("Patch"),
		"/datasources/uid/{sourceUID}/correlations/{correlationUID}",
		UpdateCorrelation,
	},

	Route{
		"GetDashboardPermissionsListByID",
		strings.ToUpper("Get"),
		"/dashboards/id/{DashboardID}/permissions",
		GetDashboardPermissionsListByID,
	},

	Route{
		"GetDashboardPermissionsListByUID",
		strings.ToUpper("Get"),
		"/dashboards/uid/{uid}/permissions",
		GetDashboardPermissionsListByUID,
	},

	Route{
		"UpdateDashboardPermissionsByID",
		strings.ToUpper("Post"),
		"/dashboards/id/{DashboardID}/permissions",
		UpdateDashboardPermissionsByID,
	},

	Route{
		"UpdateDashboardPermissionsByUID",
		strings.ToUpper("Post"),
		"/dashboards/uid/{uid}/permissions",
		UpdateDashboardPermissionsByUID,
	},

	Route{
		"CreatePublicDashboard",
		strings.ToUpper("Post"),
		"/dashboards/uid/{dashboardUid}/public-dashboards",
		CreatePublicDashboard,
	},

	Route{
		"DeletePublicDashboard",
		strings.ToUpper("Delete"),
		"/dashboards/uid/{dashboardUid}/public-dashboards/{uid}",
		DeletePublicDashboard,
	},

	Route{
		"GetPublicAnnotations",
		strings.ToUpper("Get"),
		"/public/dashboards/{accessToken}/annotations",
		GetPublicAnnotations,
	},

	Route{
		"GetPublicDashboard",
		strings.ToUpper("Get"),
		"/dashboards/uid/{dashboardUid}/public-dashboards",
		GetPublicDashboard,
	},

	Route{
		"ListPublicDashboards",
		strings.ToUpper("Get"),
		"/dashboards/public-dashboards",
		ListPublicDashboards,
	},

	Route{
		"QueryPublicDashboard",
		strings.ToUpper("Post"),
		"/public/dashboards/{accessToken}/panels/{panelId}/query",
		QueryPublicDashboard,
	},

	Route{
		"UpdatePublicDashboard",
		strings.ToUpper("Patch"),
		"/dashboards/uid/{dashboardUid}/public-dashboards/{uid}",
		UpdatePublicDashboard,
	},

	Route{
		"ViewPublicDashboard",
		strings.ToUpper("Get"),
		"/public/dashboards/{accessToken}",
		ViewPublicDashboard,
	},

	Route{
		"GetDashboardVersionByID",
		strings.ToUpper("Get"),
		"/dashboards/id/{DashboardID}/versions/{DashboardVersionID}",
		GetDashboardVersionByID,
	},

	Route{
		"GetDashboardVersionByUID",
		strings.ToUpper("Get"),
		"/dashboards/uid/{uid}/versions/{DashboardVersionID}",
		GetDashboardVersionByUID,
	},

	Route{
		"GetDashboardVersionsByID",
		strings.ToUpper("Get"),
		"/dashboards/id/{DashboardID}/versions",
		GetDashboardVersionsByID,
	},

	Route{
		"GetDashboardVersionsByUID",
		strings.ToUpper("Get"),
		"/dashboards/uid/{uid}/versions",
		GetDashboardVersionsByUID,
	},

	Route{
		"RestoreDashboardVersionByID",
		strings.ToUpper("Post"),
		"/dashboards/id/{DashboardID}/restore",
		RestoreDashboardVersionByID,
	},

	Route{
		"RestoreDashboardVersionByUID",
		strings.ToUpper("Post"),
		"/dashboards/uid/{uid}/restore",
		RestoreDashboardVersionByUID,
	},

	Route{
		"CalculateDashboardDiff",
		strings.ToUpper("Post"),
		"/dashboards/calculate-diff",
		CalculateDashboardDiff,
	},

	Route{
		"DeleteDashboardByUID",
		strings.ToUpper("Delete"),
		"/dashboards/uid/{uid}",
		DeleteDashboardByUID,
	},

	Route{
		"GetDashboardByUID",
		strings.ToUpper("Get"),
		"/dashboards/uid/{uid}",
		GetDashboardByUID,
	},

	Route{
		"GetDashboardTags",
		strings.ToUpper("Get"),
		"/dashboards/tags",
		GetDashboardTags,
	},

	Route{
		"GetHomeDashboard",
		strings.ToUpper("Get"),
		"/dashboards/home",
		GetHomeDashboard,
	},

	Route{
		"HardDeleteDashboardByUID",
		strings.ToUpper("Delete"),
		"/dashboards/uid/{uid}/trash",
		HardDeleteDashboardByUID,
	},

	Route{
		"ImportDashboard",
		strings.ToUpper("Post"),
		"/dashboards/import",
		ImportDashboard,
	},

	Route{
		"PostDashboard",
		strings.ToUpper("Post"),
		"/dashboards/db",
		PostDashboard,
	},

	Route{
		"RestoreDeletedDashboardByUID",
		strings.ToUpper("Patch"),
		"/dashboards/uid/{uid}/trash",
		RestoreDeletedDashboardByUID,
	},

	Route{
		"AddDataSource",
		strings.ToUpper("Post"),
		"/datasources",
		AddDataSource,
	},

	Route{
		"CallDatasourceResourceByID",
		strings.ToUpper("Get"),
		"/datasources/{id}/resources/{datasource_proxy_route}",
		CallDatasourceResourceByID,
	},

	Route{
		"CallDatasourceResourceWithUID",
		strings.ToUpper("Get"),
		"/datasources/uid/{uid}/resources/{datasource_proxy_route}",
		CallDatasourceResourceWithUID,
	},

	Route{
		"CheckDatasourceHealthByID",
		strings.ToUpper("Get"),
		"/datasources/{id}/health",
		CheckDatasourceHealthByID,
	},

	Route{
		"CheckDatasourceHealthWithUID",
		strings.ToUpper("Get"),
		"/datasources/uid/{uid}/health",
		CheckDatasourceHealthWithUID,
	},

	Route{
		"DatasourceProxyDELETEByUIDcalls",
		strings.ToUpper("Delete"),
		"/datasources/proxy/uid/{uid}/{datasource_proxy_route}",
		DatasourceProxyDELETEByUIDcalls,
	},

	Route{
		"DatasourceProxyDELETEcalls",
		strings.ToUpper("Delete"),
		"/datasources/proxy/{id}/{datasource_proxy_route}",
		DatasourceProxyDELETEcalls,
	},

	Route{
		"DatasourceProxyGETByUIDcalls",
		strings.ToUpper("Get"),
		"/datasources/proxy/uid/{uid}/{datasource_proxy_route}",
		DatasourceProxyGETByUIDcalls,
	},

	Route{
		"DatasourceProxyGETcalls",
		strings.ToUpper("Get"),
		"/datasources/proxy/{id}/{datasource_proxy_route}",
		DatasourceProxyGETcalls,
	},

	Route{
		"DatasourceProxyPOSTByUIDcalls",
		strings.ToUpper("Post"),
		"/datasources/proxy/uid/{uid}/{datasource_proxy_route}",
		DatasourceProxyPOSTByUIDcalls,
	},

	Route{
		"DatasourceProxyPOSTcalls",
		strings.ToUpper("Post"),
		"/datasources/proxy/{id}/{datasource_proxy_route}",
		DatasourceProxyPOSTcalls,
	},

	Route{
		"DeleteDataSourceByID",
		strings.ToUpper("Delete"),
		"/datasources/{id}",
		DeleteDataSourceByID,
	},

	Route{
		"DeleteDataSourceByName",
		strings.ToUpper("Delete"),
		"/datasources/name/{name}",
		DeleteDataSourceByName,
	},

	Route{
		"DeleteDataSourceByUID",
		strings.ToUpper("Delete"),
		"/datasources/uid/{uid}",
		DeleteDataSourceByUID,
	},

	Route{
		"GetDataSourceByID",
		strings.ToUpper("Get"),
		"/datasources/{id}",
		GetDataSourceByID,
	},

	Route{
		"GetDataSourceByName",
		strings.ToUpper("Get"),
		"/datasources/name/{name}",
		GetDataSourceByName,
	},

	Route{
		"GetDataSourceByUID",
		strings.ToUpper("Get"),
		"/datasources/uid/{uid}",
		GetDataSourceByUID,
	},

	Route{
		"GetDataSourceIdByName",
		strings.ToUpper("Get"),
		"/datasources/id/{name}",
		GetDataSourceIdByName,
	},

	Route{
		"GetDataSources",
		strings.ToUpper("Get"),
		"/datasources",
		GetDataSources,
	},

	Route{
		"UpdateDataSourceByID",
		strings.ToUpper("Put"),
		"/datasources/{id}",
		UpdateDataSourceByID,
	},

	Route{
		"UpdateDataSourceByUID",
		strings.ToUpper("Put"),
		"/datasources/uid/{uid}",
		UpdateDataSourceByUID,
	},

	Route{
		"ListDevices",
		strings.ToUpper("Get"),
		"/stats",
		ListDevices,
	},

	Route{
		"SearchDevices",
		strings.ToUpper("Post"),
		"/search",
		SearchDevices,
	},

	Route{
		"QueryMetricsWithExpressions",
		strings.ToUpper("Post"),
		"/ds/query",
		QueryMetricsWithExpressions,
	},

	Route{
		"AddTeamGroupApi",
		strings.ToUpper("Post"),
		"/teams/{teamId}/groups",
		AddTeamGroupApi,
	},

	Route{
		"AddTeamRole",
		strings.ToUpper("Post"),
		"/access-control/teams/{teamId}/roles",
		AddTeamRole,
	},

	Route{
		"AddUserRole",
		strings.ToUpper("Post"),
		"/access-control/users/{userId}/roles",
		AddUserRole,
	},

	Route{
		"AdminProvisioningReloadAccessControl",
		strings.ToUpper("Post"),
		"/admin/provisioning/access-control/reload",
		AdminProvisioningReloadAccessControl,
	},

	Route{
		"CleanDataSourceCache",
		strings.ToUpper("Post"),
		"/datasources/{dataSourceUID}/cache/clean",
		CleanDataSourceCache,
	},

	Route{
		"CreateGroupMappings",
		strings.ToUpper("Post"),
		"/groupsync/groups/{group_id}",
		CreateGroupMappings,
	},

	Route{
		"CreateRecordingRule",
		strings.ToUpper("Post"),
		"/recording-rules",
		CreateRecordingRule,
	},

	Route{
		"CreateRecordingRuleWriteTarget",
		strings.ToUpper("Post"),
		"/recording-rules/writer",
		CreateRecordingRuleWriteTarget,
	},

	Route{
		"CreateReport",
		strings.ToUpper("Post"),
		"/reports",
		CreateReport,
	},

	Route{
		"CreateRole",
		strings.ToUpper("Post"),
		"/access-control/roles",
		CreateRole,
	},

	Route{
		"DeleteGroupMappings",
		strings.ToUpper("Delete"),
		"/groupsync/groups/{group_id}",
		DeleteGroupMappings,
	},

	Route{
		"DeleteLicenseToken",
		strings.ToUpper("Delete"),
		"/licensing/token",
		DeleteLicenseToken,
	},

	Route{
		"DeleteRecordingRule",
		strings.ToUpper("Delete"),
		"/recording-rules/{recordingRuleID}",
		DeleteRecordingRule,
	},

	Route{
		"DeleteRecordingRuleWriteTarget",
		strings.ToUpper("Delete"),
		"/recording-rules/writer",
		DeleteRecordingRuleWriteTarget,
	},

	Route{
		"DeleteReport",
		strings.ToUpper("Delete"),
		"/reports/{id}",
		DeleteReport,
	},

	Route{
		"DeleteRole",
		strings.ToUpper("Delete"),
		"/access-control/roles/{roleUID}",
		DeleteRole,
	},

	Route{
		"DisableDataSourceCache",
		strings.ToUpper("Post"),
		"/datasources/{dataSourceUID}/cache/disable",
		DisableDataSourceCache,
	},

	Route{
		"EnableDataSourceCache",
		strings.ToUpper("Post"),
		"/datasources/{dataSourceUID}/cache/enable",
		EnableDataSourceCache,
	},

	Route{
		"GetAccessControlStatus",
		strings.ToUpper("Get"),
		"/access-control/status",
		GetAccessControlStatus,
	},

	Route{
		"GetCustomPermissionsCSV",
		strings.ToUpper("Get"),
		"/licensing/custom-permissions-csv",
		GetCustomPermissionsCSV,
	},

	Route{
		"GetCustomPermissionsReport",
		strings.ToUpper("Get"),
		"/licensing/custom-permissions",
		GetCustomPermissionsReport,
	},

	Route{
		"GetDataSourceCacheConfig",
		strings.ToUpper("Get"),
		"/datasources/{dataSourceUID}/cache",
		GetDataSourceCacheConfig,
	},

	Route{
		"GetGroupRoles",
		strings.ToUpper("Get"),
		"/groupsync/groups/{group_id}/roles",
		GetGroupRoles,
	},

	Route{
		"GetLicenseToken",
		strings.ToUpper("Get"),
		"/licensing/token",
		GetLicenseToken,
	},

	Route{
		"GetMappedGroups",
		strings.ToUpper("Get"),
		"/groupsync/groups",
		GetMappedGroups,
	},

	Route{
		"GetMetadata",
		strings.ToUpper("Get"),
		"/saml/metadata",
		GetMetadata,
	},

	Route{
		"GetRecordingRuleWriteTarget",
		strings.ToUpper("Get"),
		"/recording-rules/writer",
		GetRecordingRuleWriteTarget,
	},

	Route{
		"GetReport",
		strings.ToUpper("Get"),
		"/reports/{id}",
		GetReport,
	},

	Route{
		"GetReportSettings",
		strings.ToUpper("Get"),
		"/reports/settings",
		GetReportSettings,
	},

	Route{
		"GetReports",
		strings.ToUpper("Get"),
		"/reports",
		GetReports,
	},

	Route{
		"GetRole",
		strings.ToUpper("Get"),
		"/access-control/roles/{roleUID}",
		GetRole,
	},

	Route{
		"GetRoleAssignments",
		strings.ToUpper("Get"),
		"/access-control/roles/{roleUID}/assignments",
		GetRoleAssignments,
	},

	Route{
		"GetSAMLLogout",
		strings.ToUpper("Get"),
		"/logout/saml",
		GetSAMLLogout,
	},

	Route{
		"GetSLO",
		strings.ToUpper("Get"),
		"/saml/slo",
		GetSLO,
	},

	Route{
		"GetSettingsImage",
		strings.ToUpper("Get"),
		"/reports/images/:image",
		GetSettingsImage,
	},

	Route{
		"GetStatus",
		strings.ToUpper("Get"),
		"/licensing/check",
		GetStatus,
	},

	Route{
		"GetSyncStatus",
		strings.ToUpper("Get"),
		"/admin/ldap-sync-status",
		GetSyncStatus,
	},

	Route{
		"GetTeamGroupsApi",
		strings.ToUpper("Get"),
		"/teams/{teamId}/groups",
		GetTeamGroupsApi,
	},

	Route{
		"GetTeamLBACRulesApi",
		strings.ToUpper("Get"),
		"/datasources/uid/{uid}/lbac/teams",
		GetTeamLBACRulesApi,
	},

	Route{
		"ListRecordingRules",
		strings.ToUpper("Get"),
		"/recording-rules",
		ListRecordingRules,
	},

	Route{
		"ListRoles",
		strings.ToUpper("Get"),
		"/access-control/roles",
		ListRoles,
	},

	Route{
		"ListTeamRoles",
		strings.ToUpper("Get"),
		"/access-control/teams/{teamId}/roles",
		ListTeamRoles,
	},

	Route{
		"ListTeamsRoles",
		strings.ToUpper("Post"),
		"/access-control/teams/roles/search",
		ListTeamsRoles,
	},

	Route{
		"ListUserRoles",
		strings.ToUpper("Get"),
		"/access-control/users/{userId}/roles",
		ListUserRoles,
	},

	Route{
		"ListUsersRoles",
		strings.ToUpper("Post"),
		"/access-control/users/roles/search",
		ListUsersRoles,
	},

	Route{
		"PostACS",
		strings.ToUpper("Post"),
		"/saml/acs",
		PostACS,
	},

	Route{
		"PostLicenseToken",
		strings.ToUpper("Post"),
		"/licensing/token",
		PostLicenseToken,
	},

	Route{
		"PostRenewLicenseToken",
		strings.ToUpper("Post"),
		"/licensing/token/renew",
		PostRenewLicenseToken,
	},

	Route{
		"PostSLO",
		strings.ToUpper("Post"),
		"/saml/slo",
		PostSLO,
	},

	Route{
		"RefreshLicenseStats",
		strings.ToUpper("Get"),
		"/licensing/refresh-stats",
		RefreshLicenseStats,
	},

	Route{
		"RemoveTeamGroupApiQuery",
		strings.ToUpper("Delete"),
		"/teams/{teamId}/groups",
		RemoveTeamGroupApiQuery,
	},

	Route{
		"RemoveTeamRole",
		strings.ToUpper("Delete"),
		"/access-control/teams/{teamId}/roles/{roleUID}",
		RemoveTeamRole,
	},

	Route{
		"RemoveUserRole",
		strings.ToUpper("Delete"),
		"/access-control/users/{userId}/roles/{roleUID}",
		RemoveUserRole,
	},

	Route{
		"RenderReportCSVs",
		strings.ToUpper("Get"),
		"/reports/render/csvs",
		RenderReportCSVs,
	},

	Route{
		"RenderReportPDFs",
		strings.ToUpper("Get"),
		"/reports/render/pdfs",
		RenderReportPDFs,
	},

	Route{
		"SaveReportSettings",
		strings.ToUpper("Post"),
		"/reports/settings",
		SaveReportSettings,
	},

	Route{
		"SearchResult",
		strings.ToUpper("Post"),
		"/access-control/assignments/search",
		SearchResult,
	},

	Route{
		"SendReport",
		strings.ToUpper("Post"),
		"/reports/email",
		SendReport,
	},

	Route{
		"SendTestEmail",
		strings.ToUpper("Post"),
		"/reports/test-email",
		SendTestEmail,
	},

	Route{
		"SetDataSourceCacheConfig",
		strings.ToUpper("Post"),
		"/datasources/{dataSourceUID}/cache",
		SetDataSourceCacheConfig,
	},

	Route{
		"SetRoleAssignments",
		strings.ToUpper("Put"),
		"/access-control/roles/{roleUID}/assignments",
		SetRoleAssignments,
	},

	Route{
		"SetTeamRoles",
		strings.ToUpper("Put"),
		"/access-control/teams/{teamId}/roles",
		SetTeamRoles,
	},

	Route{
		"SetUserRoles",
		strings.ToUpper("Put"),
		"/access-control/users/{userId}/roles",
		SetUserRoles,
	},

	Route{
		"TestCreateRecordingRule",
		strings.ToUpper("Post"),
		"/recording-rules/test",
		TestCreateRecordingRule,
	},

	Route{
		"UpdateGroupMappings",
		strings.ToUpper("Put"),
		"/groupsync/groups/{group_id}",
		UpdateGroupMappings,
	},

	Route{
		"UpdateRecordingRule",
		strings.ToUpper("Put"),
		"/recording-rules",
		UpdateRecordingRule,
	},

	Route{
		"UpdateReport",
		strings.ToUpper("Put"),
		"/reports/{id}",
		UpdateReport,
	},

	Route{
		"UpdateRole",
		strings.ToUpper("Put"),
		"/access-control/roles/{roleUID}",
		UpdateRole,
	},

	Route{
		"UpdateTeamLBACRulesApi",
		strings.ToUpper("Put"),
		"/datasources/uid/{uid}/lbac/teams",
		UpdateTeamLBACRulesApi,
	},

	Route{
		"GetFolderPermissionList",
		strings.ToUpper("Get"),
		"/folders/{folder_uid}/permissions",
		GetFolderPermissionList,
	},

	Route{
		"UpdateFolderPermissions",
		strings.ToUpper("Post"),
		"/folders/{folder_uid}/permissions",
		UpdateFolderPermissions,
	},

	Route{
		"CreateFolder",
		strings.ToUpper("Post"),
		"/folders",
		CreateFolder,
	},

	Route{
		"DeleteFolder",
		strings.ToUpper("Delete"),
		"/folders/{folder_uid}",
		DeleteFolder,
	},

	Route{
		"GetFolderByID",
		strings.ToUpper("Get"),
		"/folders/id/{folder_id}",
		GetFolderByID,
	},

	Route{
		"GetFolderByUID",
		strings.ToUpper("Get"),
		"/folders/{folder_uid}",
		GetFolderByUID,
	},

	Route{
		"GetFolderDescendantCounts",
		strings.ToUpper("Get"),
		"/folders/{folder_uid}/counts",
		GetFolderDescendantCounts,
	},

	Route{
		"GetFolders",
		strings.ToUpper("Get"),
		"/folders",
		GetFolders,
	},

	Route{
		"MoveFolder",
		strings.ToUpper("Post"),
		"/folders/{folder_uid}/move",
		MoveFolder,
	},

	Route{
		"UpdateFolder",
		strings.ToUpper("Put"),
		"/folders/{folder_uid}",
		UpdateFolder,
	},

	Route{
		"GetCurrentOrgQuota",
		strings.ToUpper("Get"),
		"/org/quotas",
		GetCurrentOrgQuota,
	},

	Route{
		"CreateGroupMappings",
		strings.ToUpper("Post"),
		"/groupsync/groups/{group_id}",
		CreateGroupMappings,
	},

	Route{
		"DeleteGroupMappings",
		strings.ToUpper("Delete"),
		"/groupsync/groups/{group_id}",
		DeleteGroupMappings,
	},

	Route{
		"GetGroupRoles",
		strings.ToUpper("Get"),
		"/groupsync/groups/{group_id}/roles",
		GetGroupRoles,
	},

	Route{
		"GetMappedGroups",
		strings.ToUpper("Get"),
		"/groupsync/groups",
		GetMappedGroups,
	},

	Route{
		"UpdateGroupMappings",
		strings.ToUpper("Put"),
		"/groupsync/groups/{group_id}",
		UpdateGroupMappings,
	},

	Route{
		"GetHealth",
		strings.ToUpper("Get"),
		"/health",
		GetHealth,
	},

	Route{
		"GetSyncStatus",
		strings.ToUpper("Get"),
		"/admin/ldap-sync-status",
		GetSyncStatus,
	},

	Route{
		"CreateLibraryElement",
		strings.ToUpper("Post"),
		"/library-elements",
		CreateLibraryElement,
	},

	Route{
		"DeleteLibraryElementByUID",
		strings.ToUpper("Delete"),
		"/library-elements/{library_element_uid}",
		DeleteLibraryElementByUID,
	},

	Route{
		"GetLibraryElementByName",
		strings.ToUpper("Get"),
		"/library-elements/name/{library_element_name}",
		GetLibraryElementByName,
	},

	Route{
		"GetLibraryElementByUID",
		strings.ToUpper("Get"),
		"/library-elements/{library_element_uid}",
		GetLibraryElementByUID,
	},

	Route{
		"GetLibraryElementConnections",
		strings.ToUpper("Get"),
		"/library-elements/{library_element_uid}/connections/",
		GetLibraryElementConnections,
	},

	Route{
		"GetLibraryElements",
		strings.ToUpper("Get"),
		"/library-elements",
		GetLibraryElements,
	},

	Route{
		"UpdateLibraryElement",
		strings.ToUpper("Patch"),
		"/library-elements/{library_element_uid}",
		UpdateLibraryElement,
	},

	Route{
		"DeleteLicenseToken",
		strings.ToUpper("Delete"),
		"/licensing/token",
		DeleteLicenseToken,
	},

	Route{
		"GetCustomPermissionsCSV",
		strings.ToUpper("Get"),
		"/licensing/custom-permissions-csv",
		GetCustomPermissionsCSV,
	},

	Route{
		"GetCustomPermissionsReport",
		strings.ToUpper("Get"),
		"/licensing/custom-permissions",
		GetCustomPermissionsReport,
	},

	Route{
		"GetLicenseToken",
		strings.ToUpper("Get"),
		"/licensing/token",
		GetLicenseToken,
	},

	Route{
		"GetStatus",
		strings.ToUpper("Get"),
		"/licensing/check",
		GetStatus,
	},

	Route{
		"PostLicenseToken",
		strings.ToUpper("Post"),
		"/licensing/token",
		PostLicenseToken,
	},

	Route{
		"PostRenewLicenseToken",
		strings.ToUpper("Post"),
		"/licensing/token/renew",
		PostRenewLicenseToken,
	},

	Route{
		"RefreshLicenseStats",
		strings.ToUpper("Get"),
		"/licensing/refresh-stats",
		RefreshLicenseStats,
	},

	Route{
		"CancelSnapshot",
		strings.ToUpper("Post"),
		"/cloudmigration/migration/{uid}/snapshot/{snapshotUid}/cancel",
		CancelSnapshot,
	},

	Route{
		"CreateCloudMigrationToken",
		strings.ToUpper("Post"),
		"/cloudmigration/token",
		CreateCloudMigrationToken,
	},

	Route{
		"CreateSession",
		strings.ToUpper("Post"),
		"/cloudmigration/migration",
		CreateSession,
	},

	Route{
		"CreateSnapshot",
		strings.ToUpper("Post"),
		"/cloudmigration/migration/{uid}/snapshot",
		CreateSnapshot,
	},

	Route{
		"DeleteCloudMigrationToken",
		strings.ToUpper("Delete"),
		"/cloudmigration/token/{uid}",
		DeleteCloudMigrationToken,
	},

	Route{
		"DeleteSession",
		strings.ToUpper("Delete"),
		"/cloudmigration/migration/{uid}",
		DeleteSession,
	},

	Route{
		"GetCloudMigrationToken",
		strings.ToUpper("Get"),
		"/cloudmigration/token",
		GetCloudMigrationToken,
	},

	Route{
		"GetSession",
		strings.ToUpper("Get"),
		"/cloudmigration/migration/{uid}",
		GetSession,
	},

	Route{
		"GetSessionList",
		strings.ToUpper("Get"),
		"/cloudmigration/migration",
		GetSessionList,
	},

	Route{
		"GetShapshotList",
		strings.ToUpper("Get"),
		"/cloudmigration/migration/{uid}/snapshots",
		GetShapshotList,
	},

	Route{
		"GetSnapshot",
		strings.ToUpper("Get"),
		"/cloudmigration/migration/{uid}/snapshot/{snapshotUid}",
		GetSnapshot,
	},

	Route{
		"UploadSnapshot",
		strings.ToUpper("Post"),
		"/cloudmigration/migration/{uid}/snapshot/{snapshotUid}/upload",
		UploadSnapshot,
	},

	Route{
		"AddOrgUserToCurrentOrg",
		strings.ToUpper("Post"),
		"/org/users",
		AddOrgUserToCurrentOrg,
	},

	Route{
		"GetCurrentOrg",
		strings.ToUpper("Get"),
		"/org",
		GetCurrentOrg,
	},

	Route{
		"GetOrgUsersForCurrentOrg",
		strings.ToUpper("Get"),
		"/org/users",
		GetOrgUsersForCurrentOrg,
	},

	Route{
		"GetOrgUsersForCurrentOrgLookup",
		strings.ToUpper("Get"),
		"/org/users/lookup",
		GetOrgUsersForCurrentOrgLookup,
	},

	Route{
		"RemoveOrgUserForCurrentOrg",
		strings.ToUpper("Delete"),
		"/org/users/{user_id}",
		RemoveOrgUserForCurrentOrg,
	},

	Route{
		"UpdateCurrentOrg",
		strings.ToUpper("Put"),
		"/org",
		UpdateCurrentOrg,
	},

	Route{
		"UpdateCurrentOrgAddress",
		strings.ToUpper("Put"),
		"/org/address",
		UpdateCurrentOrgAddress,
	},

	Route{
		"UpdateOrgUserForCurrentOrg",
		strings.ToUpper("Patch"),
		"/org/users/{user_id}",
		UpdateOrgUserForCurrentOrg,
	},

	Route{
		"AddOrgInvite",
		strings.ToUpper("Post"),
		"/org/invites",
		AddOrgInvite,
	},

	Route{
		"GetPendingOrgInvites",
		strings.ToUpper("Get"),
		"/org/invites",
		GetPendingOrgInvites,
	},

	Route{
		"RevokeInvite",
		strings.ToUpper("Delete"),
		"/org/invites/{invitation_code}/revoke",
		RevokeInvite,
	},

	Route{
		"GetOrgPreferences",
		strings.ToUpper("Get"),
		"/org/preferences",
		GetOrgPreferences,
	},

	Route{
		"PatchOrgPreferences",
		strings.ToUpper("Patch"),
		"/org/preferences",
		PatchOrgPreferences,
	},

	Route{
		"UpdateOrgPreferences",
		strings.ToUpper("Put"),
		"/org/preferences",
		UpdateOrgPreferences,
	},

	Route{
		"AddOrgUser",
		strings.ToUpper("Post"),
		"/orgs/{org_id}/users",
		AddOrgUser,
	},

	Route{
		"CreateOrg",
		strings.ToUpper("Post"),
		"/orgs",
		CreateOrg,
	},

	Route{
		"DeleteOrgByID",
		strings.ToUpper("Delete"),
		"/orgs/{org_id}",
		DeleteOrgByID,
	},

	Route{
		"GetOrgByID",
		strings.ToUpper("Get"),
		"/orgs/{org_id}",
		GetOrgByID,
	},

	Route{
		"GetOrgByName",
		strings.ToUpper("Get"),
		"/orgs/name/{org_name}",
		GetOrgByName,
	},

	Route{
		"GetOrgQuota",
		strings.ToUpper("Get"),
		"/orgs/{org_id}/quotas",
		GetOrgQuota,
	},

	Route{
		"GetOrgUsers",
		strings.ToUpper("Get"),
		"/orgs/{org_id}/users",
		GetOrgUsers,
	},

	Route{
		"RemoveOrgUser",
		strings.ToUpper("Delete"),
		"/orgs/{org_id}/users/{user_id}",
		RemoveOrgUser,
	},

	Route{
		"SearchOrgUsers",
		strings.ToUpper("Get"),
		"/orgs/{org_id}/users/search",
		SearchOrgUsers,
	},

	Route{
		"SearchOrgs",
		strings.ToUpper("Get"),
		"/orgs",
		SearchOrgs,
	},

	Route{
		"UpdateOrg",
		strings.ToUpper("Put"),
		"/orgs/{org_id}",
		UpdateOrg,
	},

	Route{
		"UpdateOrgAddress",
		strings.ToUpper("Put"),
		"/orgs/{org_id}/address",
		UpdateOrgAddress,
	},

	Route{
		"UpdateOrgQuota",
		strings.ToUpper("Put"),
		"/orgs/{org_id}/quotas/{quota_target}",
		UpdateOrgQuota,
	},

	Route{
		"UpdateOrgUser",
		strings.ToUpper("Patch"),
		"/orgs/{org_id}/users/{user_id}",
		UpdateOrgUser,
	},

	Route{
		"CreatePlaylist",
		strings.ToUpper("Post"),
		"/playlists",
		CreatePlaylist,
	},

	Route{
		"DeletePlaylist",
		strings.ToUpper("Delete"),
		"/playlists/{uid}",
		DeletePlaylist,
	},

	Route{
		"GetPlaylist",
		strings.ToUpper("Get"),
		"/playlists/{uid}",
		GetPlaylist,
	},

	Route{
		"GetPlaylistItems",
		strings.ToUpper("Get"),
		"/playlists/{uid}/items",
		GetPlaylistItems,
	},

	Route{
		"SearchPlaylists",
		strings.ToUpper("Get"),
		"/playlists",
		SearchPlaylists,
	},

	Route{
		"UpdatePlaylist",
		strings.ToUpper("Put"),
		"/playlists/{uid}",
		UpdatePlaylist,
	},

	Route{
		"RouteDeleteAlertRule",
		strings.ToUpper("Delete"),
		"/v1/provisioning/alert-rules/{UID}",
		RouteDeleteAlertRule,
	},

	Route{
		"RouteDeleteAlertRuleGroup",
		strings.ToUpper("Delete"),
		"/v1/provisioning/folder/{FolderUID}/rule-groups/{Group}",
		RouteDeleteAlertRuleGroup,
	},

	Route{
		"RouteDeleteContactpoints",
		strings.ToUpper("Delete"),
		"/v1/provisioning/contact-points/{UID}",
		RouteDeleteContactpoints,
	},

	Route{
		"RouteDeleteMuteTiming",
		strings.ToUpper("Delete"),
		"/v1/provisioning/mute-timings/{name}",
		RouteDeleteMuteTiming,
	},

	Route{
		"RouteDeleteTemplate",
		strings.ToUpper("Delete"),
		"/v1/provisioning/templates/{name}",
		RouteDeleteTemplate,
	},

	Route{
		"RouteExportMuteTiming",
		strings.ToUpper("Get"),
		"/v1/provisioning/mute-timings/{name}/export",
		RouteExportMuteTiming,
	},

	Route{
		"RouteExportMuteTimings",
		strings.ToUpper("Get"),
		"/v1/provisioning/mute-timings/export",
		RouteExportMuteTimings,
	},

	Route{
		"RouteGetAlertRule",
		strings.ToUpper("Get"),
		"/v1/provisioning/alert-rules/{UID}",
		RouteGetAlertRule,
	},

	Route{
		"RouteGetAlertRuleExport",
		strings.ToUpper("Get"),
		"/v1/provisioning/alert-rules/{UID}/export",
		RouteGetAlertRuleExport,
	},

	Route{
		"RouteGetAlertRuleGroup",
		strings.ToUpper("Get"),
		"/v1/provisioning/folder/{FolderUID}/rule-groups/{Group}",
		RouteGetAlertRuleGroup,
	},

	Route{
		"RouteGetAlertRuleGroupExport",
		strings.ToUpper("Get"),
		"/v1/provisioning/folder/{FolderUID}/rule-groups/{Group}/export",
		RouteGetAlertRuleGroupExport,
	},

	Route{
		"RouteGetAlertRules",
		strings.ToUpper("Get"),
		"/v1/provisioning/alert-rules",
		RouteGetAlertRules,
	},

	Route{
		"RouteGetAlertRulesExport",
		strings.ToUpper("Get"),
		"/v1/provisioning/alert-rules/export",
		RouteGetAlertRulesExport,
	},

	Route{
		"RouteGetContactpoints",
		strings.ToUpper("Get"),
		"/v1/provisioning/contact-points",
		RouteGetContactpoints,
	},

	Route{
		"RouteGetContactpointsExport",
		strings.ToUpper("Get"),
		"/v1/provisioning/contact-points/export",
		RouteGetContactpointsExport,
	},

	Route{
		"RouteGetMuteTiming",
		strings.ToUpper("Get"),
		"/v1/provisioning/mute-timings/{name}",
		RouteGetMuteTiming,
	},

	Route{
		"RouteGetMuteTimings",
		strings.ToUpper("Get"),
		"/v1/provisioning/mute-timings",
		RouteGetMuteTimings,
	},

	Route{
		"RouteGetPolicyTree",
		strings.ToUpper("Get"),
		"/v1/provisioning/policies",
		RouteGetPolicyTree,
	},

	Route{
		"RouteGetPolicyTreeExport",
		strings.ToUpper("Get"),
		"/v1/provisioning/policies/export",
		RouteGetPolicyTreeExport,
	},

	Route{
		"RouteGetTemplate",
		strings.ToUpper("Get"),
		"/v1/provisioning/templates/{name}",
		RouteGetTemplate,
	},

	Route{
		"RouteGetTemplates",
		strings.ToUpper("Get"),
		"/v1/provisioning/templates",
		RouteGetTemplates,
	},

	Route{
		"RoutePostAlertRule",
		strings.ToUpper("Post"),
		"/v1/provisioning/alert-rules",
		RoutePostAlertRule,
	},

	Route{
		"RoutePostContactpoints",
		strings.ToUpper("Post"),
		"/v1/provisioning/contact-points",
		RoutePostContactpoints,
	},

	Route{
		"RoutePostMuteTiming",
		strings.ToUpper("Post"),
		"/v1/provisioning/mute-timings",
		RoutePostMuteTiming,
	},

	Route{
		"RoutePutAlertRule",
		strings.ToUpper("Put"),
		"/v1/provisioning/alert-rules/{UID}",
		RoutePutAlertRule,
	},

	Route{
		"RoutePutAlertRuleGroup",
		strings.ToUpper("Put"),
		"/v1/provisioning/folder/{FolderUID}/rule-groups/{Group}",
		RoutePutAlertRuleGroup,
	},

	Route{
		"RoutePutContactpoint",
		strings.ToUpper("Put"),
		"/v1/provisioning/contact-points/{UID}",
		RoutePutContactpoint,
	},

	Route{
		"RoutePutMuteTiming",
		strings.ToUpper("Put"),
		"/v1/provisioning/mute-timings/{name}",
		RoutePutMuteTiming,
	},

	Route{
		"RoutePutPolicyTree",
		strings.ToUpper("Put"),
		"/v1/provisioning/policies",
		RoutePutPolicyTree,
	},

	Route{
		"RoutePutTemplate",
		strings.ToUpper("Put"),
		"/v1/provisioning/templates/{name}",
		RoutePutTemplate,
	},

	Route{
		"RouteResetPolicyTree",
		strings.ToUpper("Delete"),
		"/v1/provisioning/policies",
		RouteResetPolicyTree,
	},

	Route{
		"CreateQuery",
		strings.ToUpper("Post"),
		"/query-history",
		CreateQuery,
	},

	Route{
		"DeleteQuery",
		strings.ToUpper("Delete"),
		"/query-history/{query_history_uid}",
		DeleteQuery,
	},

	Route{
		"PatchQueryComment",
		strings.ToUpper("Patch"),
		"/query-history/{query_history_uid}",
		PatchQueryComment,
	},

	Route{
		"SearchQueries",
		strings.ToUpper("Get"),
		"/query-history",
		SearchQueries,
	},

	Route{
		"StarQuery",
		strings.ToUpper("Post"),
		"/query-history/star/{query_history_uid}",
		StarQuery,
	},

	Route{
		"UnstarQuery",
		strings.ToUpper("Delete"),
		"/query-history/star/{query_history_uid}",
		UnstarQuery,
	},

	Route{
		"CreateRecordingRule",
		strings.ToUpper("Post"),
		"/recording-rules",
		CreateRecordingRule,
	},

	Route{
		"CreateRecordingRuleWriteTarget",
		strings.ToUpper("Post"),
		"/recording-rules/writer",
		CreateRecordingRuleWriteTarget,
	},

	Route{
		"DeleteRecordingRule",
		strings.ToUpper("Delete"),
		"/recording-rules/{recordingRuleID}",
		DeleteRecordingRule,
	},

	Route{
		"DeleteRecordingRuleWriteTarget",
		strings.ToUpper("Delete"),
		"/recording-rules/writer",
		DeleteRecordingRuleWriteTarget,
	},

	Route{
		"GetRecordingRuleWriteTarget",
		strings.ToUpper("Get"),
		"/recording-rules/writer",
		GetRecordingRuleWriteTarget,
	},

	Route{
		"ListRecordingRules",
		strings.ToUpper("Get"),
		"/recording-rules",
		ListRecordingRules,
	},

	Route{
		"TestCreateRecordingRule",
		strings.ToUpper("Post"),
		"/recording-rules/test",
		TestCreateRecordingRule,
	},

	Route{
		"UpdateRecordingRule",
		strings.ToUpper("Put"),
		"/recording-rules",
		UpdateRecordingRule,
	},

	Route{
		"CreateReport",
		strings.ToUpper("Post"),
		"/reports",
		CreateReport,
	},

	Route{
		"DeleteReport",
		strings.ToUpper("Delete"),
		"/reports/{id}",
		DeleteReport,
	},

	Route{
		"GetReport",
		strings.ToUpper("Get"),
		"/reports/{id}",
		GetReport,
	},

	Route{
		"GetReportSettings",
		strings.ToUpper("Get"),
		"/reports/settings",
		GetReportSettings,
	},

	Route{
		"GetReports",
		strings.ToUpper("Get"),
		"/reports",
		GetReports,
	},

	Route{
		"GetSettingsImage",
		strings.ToUpper("Get"),
		"/reports/images/:image",
		GetSettingsImage,
	},

	Route{
		"RenderReportCSVs",
		strings.ToUpper("Get"),
		"/reports/render/csvs",
		RenderReportCSVs,
	},

	Route{
		"RenderReportPDFs",
		strings.ToUpper("Get"),
		"/reports/render/pdfs",
		RenderReportPDFs,
	},

	Route{
		"SaveReportSettings",
		strings.ToUpper("Post"),
		"/reports/settings",
		SaveReportSettings,
	},

	Route{
		"SendReport",
		strings.ToUpper("Post"),
		"/reports/email",
		SendReport,
	},

	Route{
		"SendTestEmail",
		strings.ToUpper("Post"),
		"/reports/test-email",
		SendTestEmail,
	},

	Route{
		"UpdateReport",
		strings.ToUpper("Put"),
		"/reports/{id}",
		UpdateReport,
	},

	Route{
		"GetMetadata",
		strings.ToUpper("Get"),
		"/saml/metadata",
		GetMetadata,
	},

	Route{
		"GetSAMLLogout",
		strings.ToUpper("Get"),
		"/logout/saml",
		GetSAMLLogout,
	},

	Route{
		"GetSLO",
		strings.ToUpper("Get"),
		"/saml/slo",
		GetSLO,
	},

	Route{
		"PostACS",
		strings.ToUpper("Post"),
		"/saml/acs",
		PostACS,
	},

	Route{
		"PostSLO",
		strings.ToUpper("Post"),
		"/saml/slo",
		PostSLO,
	},

	Route{
		"ListSortOptions",
		strings.ToUpper("Get"),
		"/search/sorting",
		ListSortOptions,
	},

	Route{
		"Search",
		strings.ToUpper("Get"),
		"/search",
		Search,
	},

	Route{
		"CreateServiceAccount",
		strings.ToUpper("Post"),
		"/serviceaccounts",
		CreateServiceAccount,
	},

	Route{
		"CreateToken",
		strings.ToUpper("Post"),
		"/serviceaccounts/{serviceAccountId}/tokens",
		CreateToken,
	},

	Route{
		"DeleteServiceAccount",
		strings.ToUpper("Delete"),
		"/serviceaccounts/{serviceAccountId}",
		DeleteServiceAccount,
	},

	Route{
		"DeleteToken",
		strings.ToUpper("Delete"),
		"/serviceaccounts/{serviceAccountId}/tokens/{tokenId}",
		DeleteToken,
	},

	Route{
		"ListTokens",
		strings.ToUpper("Get"),
		"/serviceaccounts/{serviceAccountId}/tokens",
		ListTokens,
	},

	Route{
		"RetrieveServiceAccount",
		strings.ToUpper("Get"),
		"/serviceaccounts/{serviceAccountId}",
		RetrieveServiceAccount,
	},

	Route{
		"SearchOrgServiceAccountsWithPaging",
		strings.ToUpper("Get"),
		"/serviceaccounts/search",
		SearchOrgServiceAccountsWithPaging,
	},

	Route{
		"UpdateServiceAccount",
		strings.ToUpper("Patch"),
		"/serviceaccounts/{serviceAccountId}",
		UpdateServiceAccount,
	},

	Route{
		"ChangeUserPassword",
		strings.ToUpper("Put"),
		"/user/password",
		ChangeUserPassword,
	},

	Route{
		"ClearHelpFlags",
		strings.ToUpper("Get"),
		"/user/helpflags/clear",
		ClearHelpFlags,
	},

	Route{
		"GetSignedInUser",
		strings.ToUpper("Get"),
		"/user",
		GetSignedInUser,
	},

	Route{
		"GetSignedInUserOrgList",
		strings.ToUpper("Get"),
		"/user/orgs",
		GetSignedInUserOrgList,
	},

	Route{
		"GetSignedInUserTeamList",
		strings.ToUpper("Get"),
		"/user/teams",
		GetSignedInUserTeamList,
	},

	Route{
		"GetUserAuthTokens",
		strings.ToUpper("Get"),
		"/user/auth-tokens",
		GetUserAuthTokens,
	},

	Route{
		"GetUserQuotas",
		strings.ToUpper("Get"),
		"/user/quotas",
		GetUserQuotas,
	},

	Route{
		"RevokeUserAuthToken",
		strings.ToUpper("Post"),
		"/user/revoke-auth-token",
		RevokeUserAuthToken,
	},

	Route{
		"SetHelpFlag",
		strings.ToUpper("Put"),
		"/user/helpflags/{flag_id}",
		SetHelpFlag,
	},

	Route{
		"StarDashboard",
		strings.ToUpper("Post"),
		"/user/stars/dashboard/{dashboard_id}",
		StarDashboard,
	},

	Route{
		"StarDashboardByUID",
		strings.ToUpper("Post"),
		"/user/stars/dashboard/uid/{dashboard_uid}",
		StarDashboardByUID,
	},

	Route{
		"UnstarDashboard",
		strings.ToUpper("Delete"),
		"/user/stars/dashboard/{dashboard_id}",
		UnstarDashboard,
	},

	Route{
		"UnstarDashboardByUID",
		strings.ToUpper("Delete"),
		"/user/stars/dashboard/uid/{dashboard_uid}",
		UnstarDashboardByUID,
	},

	Route{
		"UpdateSignedInUser",
		strings.ToUpper("Put"),
		"/user",
		UpdateSignedInUser,
	},

	Route{
		"UserSetUsingOrg",
		strings.ToUpper("Post"),
		"/user/using/{org_id}",
		UserSetUsingOrg,
	},

	Route{
		"RetrieveJWKS",
		strings.ToUpper("Get"),
		"/signing-keys/keys",
		RetrieveJWKS,
	},

	Route{
		"CreateDashboardSnapshot",
		strings.ToUpper("Post"),
		"/snapshots",
		CreateDashboardSnapshot,
	},

	Route{
		"DeleteDashboardSnapshot",
		strings.ToUpper("Delete"),
		"/snapshots/{key}",
		DeleteDashboardSnapshot,
	},

	Route{
		"DeleteDashboardSnapshotByDeleteKey",
		strings.ToUpper("Get"),
		"/snapshots-delete/{deleteKey}",
		DeleteDashboardSnapshotByDeleteKey,
	},

	Route{
		"GetDashboardSnapshot",
		strings.ToUpper("Get"),
		"/snapshots/{key}",
		GetDashboardSnapshot,
	},

	Route{
		"GetSharingOptions",
		strings.ToUpper("Get"),
		"/snapshot/shared-options",
		GetSharingOptions,
	},

	Route{
		"SearchDashboardSnapshots",
		strings.ToUpper("Get"),
		"/dashboard/snapshots",
		SearchDashboardSnapshots,
	},

	Route{
		"GetProviderSettings",
		strings.ToUpper("Get"),
		"/v1/sso-settings/{key}",
		GetProviderSettings,
	},

	Route{
		"ListAllProvidersSettings",
		strings.ToUpper("Get"),
		"/v1/sso-settings",
		ListAllProvidersSettings,
	},

	Route{
		"RemoveProviderSettings",
		strings.ToUpper("Delete"),
		"/v1/sso-settings/{key}",
		RemoveProviderSettings,
	},

	Route{
		"UpdateProviderSettings",
		strings.ToUpper("Put"),
		"/v1/sso-settings/{key}",
		UpdateProviderSettings,
	},

	Route{
		"AddTeamGroupApi",
		strings.ToUpper("Post"),
		"/teams/{teamId}/groups",
		AddTeamGroupApi,
	},

	Route{
		"GetTeamGroupsApi",
		strings.ToUpper("Get"),
		"/teams/{teamId}/groups",
		GetTeamGroupsApi,
	},

	Route{
		"RemoveTeamGroupApiQuery",
		strings.ToUpper("Delete"),
		"/teams/{teamId}/groups",
		RemoveTeamGroupApiQuery,
	},

	Route{
		"AddTeamMember",
		strings.ToUpper("Post"),
		"/teams/{team_id}/members",
		AddTeamMember,
	},

	Route{
		"CreateTeam",
		strings.ToUpper("Post"),
		"/teams",
		CreateTeam,
	},

	Route{
		"DeleteTeamByID",
		strings.ToUpper("Delete"),
		"/teams/{team_id}",
		DeleteTeamByID,
	},

	Route{
		"GetTeamByID",
		strings.ToUpper("Get"),
		"/teams/{team_id}",
		GetTeamByID,
	},

	Route{
		"GetTeamMembers",
		strings.ToUpper("Get"),
		"/teams/{team_id}/members",
		GetTeamMembers,
	},

	Route{
		"GetTeamPreferences",
		strings.ToUpper("Get"),
		"/teams/{team_id}/preferences",
		GetTeamPreferences,
	},

	Route{
		"RemoveTeamMember",
		strings.ToUpper("Delete"),
		"/teams/{team_id}/members/{user_id}",
		RemoveTeamMember,
	},

	Route{
		"SearchTeams",
		strings.ToUpper("Get"),
		"/teams/search",
		SearchTeams,
	},

	Route{
		"SetTeamMemberships",
		strings.ToUpper("Put"),
		"/teams/{team_id}/members",
		SetTeamMemberships,
	},

	Route{
		"UpdateTeam",
		strings.ToUpper("Put"),
		"/teams/{team_id}",
		UpdateTeam,
	},

	Route{
		"UpdateTeamMember",
		strings.ToUpper("Put"),
		"/teams/{team_id}/members/{user_id}",
		UpdateTeamMember,
	},

	Route{
		"UpdateTeamPreferences",
		strings.ToUpper("Put"),
		"/teams/{team_id}/preferences",
		UpdateTeamPreferences,
	},

	Route{
		"UpdateUserEmail",
		strings.ToUpper("Get"),
		"/user/email/update",
		UpdateUserEmail,
	},

	Route{
		"GetUserPreferences",
		strings.ToUpper("Get"),
		"/user/preferences",
		GetUserPreferences,
	},

	Route{
		"PatchUserPreferences",
		strings.ToUpper("Patch"),
		"/user/preferences",
		PatchUserPreferences,
	},

	Route{
		"UpdateUserPreferences",
		strings.ToUpper("Put"),
		"/user/preferences",
		UpdateUserPreferences,
	},

	Route{
		"GetUserByID",
		strings.ToUpper("Get"),
		"/users/{user_id}",
		GetUserByID,
	},

	Route{
		"GetUserByLoginOrEmail",
		strings.ToUpper("Get"),
		"/users/lookup",
		GetUserByLoginOrEmail,
	},

	Route{
		"GetUserOrgList",
		strings.ToUpper("Get"),
		"/users/{user_id}/orgs",
		GetUserOrgList,
	},

	Route{
		"GetUserTeams",
		strings.ToUpper("Get"),
		"/users/{user_id}/teams",
		GetUserTeams,
	},

	Route{
		"SearchUsers",
		strings.ToUpper("Get"),
		"/users",
		SearchUsers,
	},

	Route{
		"SearchUsersWithPaging",
		strings.ToUpper("Get"),
		"/users/search",
		SearchUsersWithPaging,
	},

	Route{
		"UpdateUser",
		strings.ToUpper("Put"),
		"/users/{user_id}",
		UpdateUser,
	},
}
